timelogutil

package module
v0.0.0-...-80eea22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 25, 2018 License: MIT Imports: 5 Imported by: 0

README

timelogutil

Utils for use with the timelog app

Documentation

Overview

Package timelogutil contains utility functions for working with timelog.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddNewTask

func AddNewTask(task Task)

AddNewTask adds a new task to the database

func GetMongoSession

func GetMongoSession(conf Configuration) *mgo.Session

GetMongoSession takes a configuration name (s) and returns a mongo session

Types

type Configuration

type Configuration struct {
	MongoDBHost  string
	Database     string
	AuthUserName string
	AuthPassword string
}

Configuration is used for configuration properties

type Task

type Task struct {
	Time  time.Time
	Event string
}

Task describes what it is that is being worked on at any time

func GetTasksSince

func GetTasksSince(startTime time.Time) []Task

GetTasksSince returns all tasks since the date that is passed in

Jump to